==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        bi() {
            return new MoneyFlowIndexIndicator();
        }
        get_aat() {
            return 1;
        }
        constructor() {
            super();
        }
        get_abm() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get abm() {
            return this.get_abm();
        }
        get_abz() {
            return MoneyFlowIndexIndicator.$;
        }
        get abz() {
            return this.get_abz();
        }
        get ab7() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.ab8));
        }
        set ab7(a) {
            this.h(MoneyFlowIndexIndicator.ab8, a);
        }
        abs() {
            return this.ab7;
        }
        ab1(a) {
            this.ab7 = a;
        }
    }
    MoneyFlowIndexIndicator.$t = /*@__PURE__*/ markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.ab8 = /*@__PURE__*/ StrategyBasedIndicator.ab4(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        bj() {
            return new MoneyFlowIndexIndicator();
        }
        get_aa2() {
            return 1;
        }
        constructor() {
            super();
        }
        get_abv() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get abv() {
            return this.get_abv();
        }
        get_ab8() {
            return MoneyFlowIndexIndicator.$;
        }
        get ab8() {
            return this.get_ab8();
        }
        get acg() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.ach));
        }
        set acg(a) {
            this.h(MoneyFlowIndexIndicator.ach, a);
        }
        ab1() {
            return this.acg;
        }
        aca(a) {
            this.acg = a;
        }
    }
    MoneyFlowIndexIndicator.$t = /*@__PURE__*/ markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.ach = /*@__PURE__*/ StrategyBasedIndicator.acd(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();
